unit DemoHelpViewerMain;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, Vcl.StdCtrls, System.HelpIntfs,

  // DEFINE HELP_EWRITER is a compiler switch to toggle this application between HTML Help (.chm)
  // and eWriter Help (.ewriter) for a better comparison between the formats.
  //
  // Important: Make sure that only one help system is active in your application!
  // For HTML Help, include the unit "Vcl.HtmlHelpViewer" in the uses clause of your main form,
  // for eWriter Help, include "Vcl.EwriterHelpViewer". Never include both!

  {$DEFINE HELP_EWRITER}

  {$IFDEF HELP_EWRITER}
  Vcl.EwriterHelpViewer
  {$ELSE}
  Vcl.HtmlHelpViewer
  {$ENDIF}
  ;

type
  TFrmHelpViewerMain = class(TForm)
    Edit1: TEdit;
    Edit2: TEdit;
    btnShowTOC: TButton;
    btnShowHelpContext: TButton;
    btnShowTopic: TButton;
    btnIsHelpShowing: TButton;
    Edit3: TEdit;
    Edit4: TEdit;
    cbDefPos: TCheckBox;
    cbDefStayontop: TCheckBox;
    Label1: TLabel;
    Label2: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure btnShowTOCClick(Sender: TObject);
    procedure btnIsHelpShowingClick(Sender: TObject);
    procedure btnShowHelpContextClick(Sender: TObject);
    procedure btnShowTopicClick(Sender: TObject);
    function  AppOnHelp(Command: Word; Data: THelpEventData; var CallHelp: Boolean): Boolean;
    procedure cbDefPosClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  FrmHelpViewerMain: TFrmHelpViewerMain;

implementation

{$R *.dfm}


procedure TFrmHelpViewerMain.FormCreate(Sender: TObject);
begin
  Application.OnHelp := AppOnHelp; //Triggered by Delphi help system on every help call

  {$IFDEF HELP_EWRITER}
  Application.HelpFile := ExtractFilePath(application.Exename) + 'help\eWriter-Delphi-Help.ewriter';
  HelpViewer.ViewerApp := ExtractFilePath(application.Exename) + 'Redist\eViewer.exe';
  HelpViewer.UrlSyntax := 'index.html?%s.html%s';
  {$ELSE}
  Application.HelpFile := ExtractFilePath(application.Exename) + 'help\eWriter-Delphi-Help.chm';
  {$ENDIF}
end;

function TFrmHelpViewerMain.AppOnHelp(Command: Word; Data: THelpEventData; var CallHelp: Boolean): Boolean;
begin
  result := true;

  {$IFDEF HELP_EWRITER}
  if cbDefPos.Checked then
  begin
    HelpViewer.DefWindowPos := point(self.left + self.width, self.top);
    HelpViewer.DefWindowSize := point(round(self.width * 1.6), self.height);
    HelpViewer.DefStayOnTop := cbDefStayOnTop.Checked;
  end
  else begin
    HelpViewer.DefWindowPos := point(0,0);
    HelpViewer.DefWindowSize := point(0,0);
    HelpViewer.DefStayOnTop := false;
  end;
  {$ENDIF}
end;


procedure TFrmHelpViewerMain.btnShowHelpContextClick(Sender: TObject);
begin
  Application.HelpCommand(HELP_CONTEXT, 1001);
end;

procedure TFrmHelpViewerMain.btnShowTOCClick(Sender: TObject);
begin
  Application.HelpCommand(HELP_CONTENTS, 0);
end;

procedure TFrmHelpViewerMain.btnShowTopicClick(Sender: TObject);
var
  HelpSystem: IHelpSystem;
begin
  GetHelpSystem(HelpSystem);
  if assigned(HelpSystem) then
    HelpSystem.ShowTopicHelp('topic3', Application.HelpFile);
 end;

procedure TFrmHelpViewerMain.cbDefPosClick(Sender: TObject);
begin
  cbDefStayOnTop.enabled := cbDefPos.checked;
  if not cbDefStayOnTop.enabled then
    cbDefStayOnTop.checked := false;
end;

procedure TFrmHelpViewerMain.btnIsHelpShowingClick(Sender: TObject);
begin
  {$IFDEF HELP_EWRITER}
  if not HelpViewer.IsShowingHelp(Application.HelpFile) then
    showmessage('Help window is currently not showing')
  else
    if MessageDlg('Help window is showing. Click on the "Close" button to close it manually.', mtConfirmation, [mbOK, mbClose], 0) = mrClose then
      Application.HelpCommand(HELP_QUIT, 0);
  {$ELSE}
  showmessage('HTML Help (.chm) does not support this function')
  {$ENDIF}
end;


end.
